"""
Postquota
"""
import argparse
import asyncio

from postquota.server import Server


def main(argv=None):
    """Postquota entrypoint"""
    # handle cli arguments
    parser = argparse.ArgumentParser(prog="postquota")

    parser.add_argument("-v", "--verbose", action="store_true")
    parser.add_argument("-d", "--daemonize", action="store_true")
    parser.add_argument("-c", "--configuration-file", default="/etc/postquota/configuration.yaml")

    args = parser.parse_args(argv)
    server = Server(args.__dict__)

    # load and propagate configuration
    server.load_config()

    loop = asyncio.get_event_loop()
    # run server
    main_task = asyncio.ensure_future(server.start())
    server.add_signals_handler(loop, main_task)
    try:
        loop.run_until_complete(main_task)
    except asyncio.CancelledError:
        pass
    finally:
        loop.close()
